@@ -1,2 +1,6 @@
+# CSS Class Maker
 from pywebkit.css_class_maker import css_class_generator
-from pywebkit.css_class_maker import *
\ No newline at end of file
+from pywebkit.css_class_maker import *
+
+# Mathlib
+from pywebkit.mathlib import *
\ No newline at end of file
